@@ -9,11 +9,11 @@
 #          One-sample raw data
 ################################################
 #' Mable fit of one-sample raw data with an optimal or given degree.
-#' @param x one sample data
-#' @param M an positive integer or a vector \code{(m0,m1)}. If \code{M=m} or \code{m0=m1=m},
+#' @param x a (non-empty) numeric vector of data values.
+#' @param M a positive integer or a vector \code{(m0, m1)}. If \code{M = m} or \code{m0 = m1 = m},
 #'   then \code{m} is a preselected degree. If \code{m0<m1} it specifies the set of
 #'   consective candidate model degrees \code{m0:m1} for searching an optimal degree,
-#'   where $\code{m1-m0>3}.
+#'   where \code{m1-m0>3}.
 #' @param interval a vector containing the endpoints of supporting/truncation interval
 #' @param IC information criterion(s) in addition to Bayesian information criterion (BIC). Current choices are
 #'  "aic" (Akaike information criterion) and/or
@@ -26,9 +26,9 @@
 #'  or a preselected model degree \code{m}.
 #' @details
 #'  Any continuous density function \eqn{f} on a known closed supporting interval \eqn{[a,b]} can be
-#'  estimated by Bernstein polynomial \eqn{f_m(x; p)=\sum_{i=0}^m p_i\beta_{mi}[(x-a)/(b-a)]},
-#'  where \eqn{p=(p_0,\ldots,p_m}, \eqn{p_i\ge 0}, \eqn{\sum_{i=0}^m p_i=1} and
-#'  \eqn{\beta_{mi}(u)=(m+1){m\choose i}u^i(1-x)^{m-i}}, \eqn{i=0,1,\ldots,m},
+#'  estimated by Bernstein polynomial \eqn{f_m(x; p) = \sum_{i=0}^m p_i\beta_{mi}[(x-a)/(b-a)]/(b-a)},
+#'  where \eqn{p = (p_0, \ldots, p_m)}, \eqn{p_i \ge 0}, \eqn{\sum_{i=0}^m p_i = 1} and
+#'  \eqn{\beta_{mi}(u) = (m+1){m\choose i}u^i(1-x)^{m-i}}, \eqn{i = 0, 1, \ldots, m},
 #'  is the beta density with shapes \eqn{(i+1, m-i+1)}.
 #'  For each \code{m}, the MABLE of the coefficients \code{p}, the mixture proportions, are
 #'  obtained using EM algorithm. The EM iteration for each candidate \code{m} stops if either
@@ -36,20 +36,20 @@
 #'  is smaller than \code{eps} or the maximum number of iterations \code{maxit} is reached.
 #'
 #'  If \code{m0<m1}, an optimal model degree is selected as the change-point of the increments of
-#'  log-likelihood, log likelihood ratios, for \eqn{m\in\{m_0,m_0+1,\ldots,m_1\}}. Alternatively,
+#'  log-likelihood, log likelihood ratios, for \eqn{m \in \{m_0, m_0+1, \ldots, m_1\}}. Alternatively,
 #'  one can choose an optimal degree based on the BIC (Schwarz, 1978) which are evaluated at
-#'  \eqn{m\in\{m_0,m_0+1,\ldots,m_1\}}. The search for optimal degree \code{m} is stoped if either
+#'  \eqn{m \in \{m_0, m_0+1, \ldots, m_1\}}. The search for optimal degree \code{m} is stoped if either
 #'  \code{m1} is reached with a warning or the test for change-point results in a p-value \code{pval}
 #'  smaller than \code{sig.level}.  The BIC for a given degree \code{m} is calculated as in
-#'  Schwarz (1978) where the dimension of the model is \eqn{d=\#\{i: \hat p_i\ge\epsilon,
-#'   i=0,\ldots,m\}-1} and \eqn{\epsilon} is chosen as \code{.Machine$double.eps}.
+#'  Schwarz (1978) where the dimension of the model is \eqn{d = \#\{i: \hat p_i\ge\epsilon,
+#'   i = 0, \ldots, m\} - 1} and a default \eqn{\epsilon} is chosen as \code{.Machine$double.eps}.
 #' @return  A list with components
 #' \itemize{
-#'   \item \code{m} the selected/given optimal degrees by methods of change-point and BIC
-#'   \item \code{p} a list of \code{p.cp} and \code{p.bic}, the estimated \code{p} with degree \code{m}
-#'     selected by the change-point method and BIC method, respectively
+#'   \item \code{m} the selected/given optimal degree by methods of change-point
+#'   \item \code{p} the estimated vector of mixture proportions \eqn{p = (p_0, \ldots, p_m)}
+#'       with the selected/given optimal degree \code{m}
 #'   \item \code{mloglik}  the maximum log-likelihood at degree \code{m}
-#'   \item \code{support} supporting interval \code{(a,b)}
+#'   \item \code{interval} support/truncation interval \code{(a,b)}
 #'   \item \code{convergence} An integer code. 0 indicates successful completion (all the EM iterations are convergent and an optimal degree
 #'     is successfully selected in \code{M}). Possible error codes are
 #'    \itemize{
@@ -60,10 +60,10 @@
 #'  }
 #'  and, if \code{m0<m1},
 #' \itemize{
-#'   \item \code{M} the vector \code{(m0,m1)}, where \code{m1}, if greater than \code{m0} is the
+#'   \item \code{M} the vector \code{(m0, m1)}, where \code{m1}, if greater than \code{m0}, is the
 #'      largest candidate when the search stoped
-#'   \item \code{lk} log-likelihoods evaluated at \eqn{m\in\{m_0,\ldots, m_1\}}
-#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m\in\{m_0+1,\ldots, m_1\}}
+#'   \item \code{lk} log-likelihoods evaluated at \eqn{m \in \{m_0, \ldots, m_1\}}
+#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m \in \{m_0+1, \ldots, m_1\}}
 #'   \item \code{ic} a list containing the selected information criterion(s)
 #'   \item \code{pval} the p-values of the change-point tests for choosing optimal model degree
 #'   \item \code{chpts} the change-points chosen with the given candidate model degrees
@@ -79,21 +79,20 @@
 # load("Vaal.Flow.rdata")
 #'  data(Vaal.Flow)
 #'  x<-Vaal.Flow$Flow
-#'  res<-mable(x, M=c(2,100), interval=c(0, 3000), controls =
-#'         mable.ctrl(sig.level=1e-8, maxit=2000, eps=1.0e-9))
-#'  op<-par(mfrow=c(1,2),lwd=2)
+#'  res<-mable(x, M = c(2,100), interval = c(0, 3000), controls =
+#'         mable.ctrl(sig.level = 1e-8, maxit = 2000, eps = 1.0e-9))
+#'  op<-par(mfrow = c(1,2),lwd = 2)
 #'  layout(rbind(c(1, 2), c(3, 3)))
-#'  plot(res, which="likelihood", cex=.5)
-#'  plot(res, which=c("change-point"), lgd.x="topright")
-#'  hist(x, prob=TRUE, xlim=c(0,3000), ylim=c(0,.0022), breaks=100*(0:30),
-#'   main="Histogram and Densities of the Annual Flow of Vaal River",
-#'   border="dark grey",lwd=1,xlab="x", ylab="f(x)", col ="light grey")
-#'  lines(density(x, bw = "nrd0", adjust = 1), lty=4, col = 4)
-#'  lines(y<-seq(0, 3000, length=100), dlnorm(y, mean(log(x)),
-#'                    sqrt(var(log(x)))), lty=2, col=2)
-#'  plot(res, which="density", add=TRUE)
-#, types=c(1,3),colors=c(1,3))
-#'  legend("top", lty=c(1, 2, 4), col=c(1, 2, 4), bty="n",
+#'  plot(res, which = "likelihood", cex = .5)
+#'  plot(res, which = c("change-point"), lgd.x = "topright")
+#'  hist(x, prob = TRUE, xlim = c(0,3000), ylim = c(0,.0022), breaks = 100*(0:30),
+#'   main = "Histogram and Densities of the Annual Flow of Vaal River",
+#'   border = "dark grey",lwd = 1,xlab = "x", ylab = "f(x)", col  = "light grey")
+#'  lines(density(x, bw = "nrd0", adjust = 1), lty = 4, col = 4)
+#'  lines(y<-seq(0, 3000, length = 100), dlnorm(y, mean(log(x)),
+#'                    sqrt(var(log(x)))), lty = 2, col = 2)
+#'  plot(res, which = "density", add = TRUE)
+#'  legend("top", lty = c(1, 2, 4), col = c(1, 2, 4), bty = "n",
 #'  c(expression(paste("MABLE: ",hat(f)[B])),
 #'         expression(paste("Log-Normal: ",hat(f)[P])),
 #'                expression(paste("KDE: ",hat(f)[K]))))
@@ -104,25 +103,25 @@
 #'  library(mixtools)
 #'  x<-faithful$eruptions
 #'  a<-0; b<-7
-#'  v<-seq(a, b,len=512)
+#'  v<-seq(a, b,len = 512)
 #'  mu<-c(2,4.5); sig<-c(1,1)
 #'  pmix<-normalmixEM(x,.5, mu, sig)
 #'  lam<-pmix$lambda; mu<-pmix$mu; sig<-pmix$sigma
 #'  y1<-lam[1]*dnorm(v,mu[1], sig[1])+lam[2]*dnorm(v, mu[2], sig[2])
-#'  res<-mable(x, M=c(2,300), interval=c(a,b), controls =
-#'         mable.ctrl(sig.level=1e-8, maxit=2000, eps=1.0e-7))
-#'  op<-par(mfrow=c(1,2),lwd=2)
+#'  res<-mable(x, M = c(2,300), interval = c(a,b), controls  =
+#'         mable.ctrl(sig.level = 1e-8, maxit = 2000, eps = 1.0e-7))
+#'  op<-par(mfrow = c(1,2),lwd = 2)
 #'  layout(rbind(c(1, 2), c(3, 3)))
-#'  plot(res, which="likelihood")
-#'  plot(res, which="change-point")
-#'  hist(x, breaks=seq(0,7.5,len=20), xlim=c(0,7), ylim=c(0,.7),
-#'      prob =TRUE,xlab="t", ylab="f(t)", col ="light grey",
-#'      main="Histogram and Density of
+#'  plot(res, which = "likelihood")
+#'  plot(res, which = "change-point")
+#'  hist(x, breaks = seq(0,7.5,len = 20), xlim = c(0,7), ylim = c(0,.7),
+#'      prob  = TRUE,xlab = "t", ylab = "f(t)", col  = "light grey",
+#'      main = "Histogram and Density of
 #'                Duration of Eruptions of Old Faithful")
-#'  lines(density(x, bw = "nrd0", adjust = 1), lty=4, col = 4, lwd=2)
-#'  plot(res, which="density", add=TRUE)
-#'  lines(v, y1, lty=2, col=2, lwd=2)
-#'  legend("topright", lty=c(1,2,4), col=c(1,2,4), lwd=2, bty="n",
+#'  lines(density(x, bw = "nrd0", adjust = 1), lty = 4, col = 4, lwd = 2)
+#'  plot(res, which = "density", add = TRUE)
+#'  lines(v, y1, lty = 2, col = 2, lwd = 2)
+#'  legend("topright", lty = c(1,2,4), col = c(1,2,4), lwd = 2, bty = "n",
 #'       c(expression(paste("MABLE: ",hat(f)[B](x))),
 #'          expression(paste("Mixture: ",hat(f)[P](t))),
 #'          expression(paste("KDE: ",hat(f)[K](t)))))
@@ -133,9 +132,9 @@
 #' @concept Bernstein polynomial model
 # @useDynLib mable, .registration = TRUE
 #' @export
-mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
-        controls = mable.ctrl(), progress=TRUE){
-    IC <- match.arg(IC, several.ok=TRUE)
+mable<-function(x, M, interval = c(0,1), IC = c("none", "aic", "hqic", "all"),
+        controls = mable.ctrl(), progress = TRUE){
+    IC <- match.arg(IC, several.ok = TRUE)
     n<-length(x)
     xName<-deparse(substitute(x))
     a<-interval[1]
@@ -160,7 +159,7 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
         res<-.C("mable_em",
           as.integer(m), as.integer(n), as.double(p), as.double(x), as.integer(controls$maxit),
           as.double(controls$eps),  as.double(llik), as.logical(convergent), as.double(del))
-        ans<-list(p=res[[3]], m=m, mloglik=res[[7]], support=c(a,b), convergent=!res[[8]], del=res[[9]])
+        ans<-list(p=res[[3]], m=m, mloglik=res[[7]], interval=c(a,b), convergent=!res[[8]], del=res[[9]])
     }
     else{
         #p<-rep(1, 2*M[2]+2)
@@ -169,7 +168,7 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
         lr<-rep(0,k)
         bic<-rep(0,k+1)
         pval<-rep(0,k+1)
-        level=controls$sig.level
+        level<-controls$sig.level
         chpts<-rep(0,k+1)
         optim<-0#c(0,0)
         ## Call C mable_optim
@@ -178,7 +177,7 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
           as.double(eps), as.double(lk), as.double(lr), as.integer(optim),
           as.double(pval), as.double(bic), as.integer(chpts), as.double(controls$tini),
           as.logical(progress), as.integer(convergent), as.double(del), as.double(level))
-        M=res[[1]]; k<-M[2]-M[1]
+        M<-res[[1]]; k<-M[2]-M[1]
         m<-res[[9]]
         mloglik<-res[[7]][m-M[1]+1]
         lk<-res[[7]][1:(k+1)]
@@ -194,9 +193,9 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
             if(any(IC=="qhic")|| any(IC=="all")){
                 ic$QHC<-lk-2*(lk-bic)*log(log(n))/log(n)}
         }
-        ans<-list(p=res[[3]][1:(m[1]+1)], #p.bic=res[[3]][(m[1]+2):(m[1]+m[2]+2)]),
+        ans<-list(p=res[[3]][1:(m[1]+1)],
             m=m, mloglik=mloglik, lk=lk, lr=res[[8]][1:k], M=M,
-            support=c(a,b), pval=res[[10]][1:(k+1)], ic=ic,
+            interval=c(a,b), pval=res[[10]][1:(k+1)], ic=ic,
             chpts=res[[12]][1:(k+1)]+M[1], convergence=res[[15]], delta=res[[16]])
     }
     ans$xNames<-xName
@@ -210,11 +209,11 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
 #' Mable fit of one-sample grouped data by an optimal or a preselected model degree
 #' @param x vector of frequencies
 #' @param breaks class interval end points
-#' @param M an positive integer or a vector \code{(m0,m1)}. If \code{M=m} or \code{m0=m1=m},
+#' @param M a positive integer or a vector \code{(m0, m1)}. If \code{M = m} or \code{m0 = m1 = m},
 #'   then \code{m} is a preselected degree. If \code{m0<m1} it specifies the set of
 #'   consective candidate model degrees \code{m0:m1} for searching an optimal degree,
-#'   where $\code{m1-m0>3}.
-#' @param interval a vector containing the endpoints of supporting/truncation interval
+#'   where \code{m1-m0>3}.
+#' @param interval a vector containing the endpoints of support/truncation interval
 #' @param IC information criterion(s) in addition to Bayesian information criterion (BIC). Current choices are
 #'  "aic" (Akaike information criterion) and/or
 #'  "qhic" (Hannan–Quinn information criterion).
@@ -225,10 +224,10 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
 #'  one-sample grouped data with an optimal selected by the change-point method among \code{m0:m1}
 #'  or a preselected model degree \code{m}.
 #' @details
-#'  Any continuous density function \eqn{f} on a known closed supporting interval \eqn{[a,b]} can be
-#'  estimated by Bernstein polynomial \eqn{f_m(x; p)=\sum_{i=0}^m p_i\beta_{mi}[(x-a)/(b-a)]},
-#'  where \eqn{p=(p_0,\ldots,p_m}, \eqn{p_i\ge 0}, \eqn{\sum_{i=0}^m p_i=1} and
-#'  \eqn{\beta_{mi}(u)=(m+1){m\choose i}u^i(1-x)^{m-i}}, \eqn{i=0,1,\ldots,m},
+#'  Any continuous density function \eqn{f} on a known closed supporting interval \eqn{[a, b]} can be
+#'  estimated by Bernstein polynomial \eqn{f_m(x; p) = \sum_{i=0}^m p_i\beta_{mi}[(x-a)/(b-a)]/(b-a)},
+#'  where \eqn{p = (p_0, \ldots, p_m)}, \eqn{p_i\ge 0}, \eqn{\sum_{i=0}^m p_i=1} and
+#'  \eqn{\beta_{mi}(u) = (m+1){m\choose i}u^i(1-x)^{m-i}}, \eqn{i = 0, 1, \ldots, m},
 #'  is the beta density with shapes \eqn{(i+1, m-i+1)}.
 #'  For each \code{m}, the MABLE of the coefficients \code{p}, the mixture proportions, are
 #'  obtained using EM algorithm. The EM iteration for each candidate \code{m} stops if either
@@ -236,35 +235,35 @@ mable<-function(x, M, interval=c(0,1), IC=c("none", "aic", "hqic", "all"),
 #'  is smaller than \code{eps} or the maximum number of iterations \code{maxit} is reached.
 #'
 #'  If \code{m0<m1}, an optimal model degree is selected as the change-point of the increments of
-#'  log-likelihood, log likelihood ratios, for \eqn{m\in\{m_0,m_0+1,\ldots,m_1\}}. Alternatively,
+#'  log-likelihood, log likelihood ratios, for \eqn{m \in \{m_0, m_0+1, \ldots, m_1\}}. Alternatively,
 #'  one can choose an optimal degree based on the BIC (Schwarz, 1978) which are evaluated at
-#'  \eqn{m\in\{m_0,m_0+1,\ldots,m_1\}}. The search for optimal degree \code{m} is stoped if either
+#'  \eqn{m \in \{m_0, m_0+1, \ldots, m_1\}}. The search for optimal degree \code{m} is stoped if either
 #'  \code{m1} is reached with a warning or the test for change-point results in a p-value \code{pval}
 #'  smaller than \code{sig.level}.  The BIC for a given degree \code{m} is calculated as in
-#'  Schwarz (1978) where the dimension of the model is \eqn{d=\#\{i: \hat p_i\ge\epsilon,
-#'   i=0,\ldots,m\}-1} and \eqn{\epsilon} is chosen as \code{.Machine$double.eps}.
+#'  Schwarz (1978) where the dimension of the model is \eqn{d=\#\{i: \hat p_i \ge \epsilon,
+#'  i = 0, \ldots, m\} - 1} and a default \eqn{\epsilon} is chosen as \code{.Machine$double.eps}.
 #' @return A list with components
 #' \itemize{
-#'   \item \code{m} the selected/given optimal degree by the method of change-point #and BIC
-#'   \item \code{p} #a list of \code{p.cp} and \code{p.bic},
-#'      the estimated \code{p} with degree \code{m}
-#'     selected by the change-point method #and BIC method, respectively
+#'   \item \code{m} the given/selected optimal degree by the method of change-point
+#'   \item \code{p} the estimated \code{p} with degree \code{m}
 #'   \item \code{mloglik}  the maximum log-likelihood at degree \code{m}
-#'   \item \code{support} supporting interval \code{(a,b)}
-#'   \item \code{convergence} An integer code. 0 indicates successful completion (all the EM iterations are convergent and an optimal degree
+#'   \item \code{interval} supporting interval \code{(a, b)}
+#'   \item \code{convergence} An integer code. 0 indicates successful completion
+#'    (all the EM iterations are convergent and an optimal degree
 #'     is successfully selected in \code{M}). Possible error codes are
 #'    \itemize{
-#'       \item 1, indicates that the iteration limit \code{maxit} had been reached in at least one EM iteration;
+#'       \item 1, indicates that the iteration limit \code{maxit} had been
+#'           reached in at least one EM iteration;
 #'       \item 2, the search did not finish before \code{m1}.
 #'     }
 #'   \item \code{delta} the convergence criterion \code{delta} value
 #'  }
 #'  and, if \code{m0<m1},
 #' \itemize{
-#'   \item \code{M} the vector \code{(m0,m1)}, where \code{m1}, if greater than \code{m0} is the
+#'   \item \code{M} the vector \code{(m0, m1)}, where \code{m1}, if greater than \code{m0}, is the
 #'      largest candidate when the search stoped
-#'   \item \code{lk} log-likelihoods evaluated at \eqn{m\in\{m_0,\ldots, m_1\}}
-#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m\in\{m_0+1,\ldots, m_1\}}
+#'   \item \code{lk} log-likelihoods evaluated at \eqn{m \in \{m_0, \ldots, m_1\}}
+#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m \in \{m_0+1, \ldots, m_1\}}
 #'   \item \code{ic} a list containing the selected information criterion(s)
 #'   \item \code{pval} the p-values of the change-point tests for choosing optimal model degree
 #'   \item \code{chpts} the change-points chosen with the given candidate model degrees
@@ -328,14 +327,14 @@ mable.group<-function(x, breaks, M, interval=c(0, 1), IC=c("none", "aic", "hqic"
           as.integer(m), as.integer(x), as.integer(N), as.double(p), as.double(t),
           as.integer(controls$maxit), as.double(controls$eps),  as.double(llik),
           as.logical(convergence), as.double(del))
-        ans<-list(p=res[[4]], m=m, mloglik=res[[8]], support=c(a,b), convergence=!res[[9]], del=res[[10]])
+        ans<-list(p=res[[4]], m=m, mloglik=res[[8]], interval=c(a,b), convergence=!res[[9]], del=res[[10]])
     }
     else{
         lk<-rep(0, k+1)
         lr<-rep(0, k)
         bic<-rep(0,k+1)
         pval<-rep(0,k+1)
-        level=controls$sig.level
+        level<-controls$sig.level
         chpts<-rep(0,k+1)
         #p<-rep(1, 2*M[2]+2)
         #optim<-c(0,0)
@@ -368,7 +367,7 @@ mable.group<-function(x, breaks, M, interval=c(0, 1), IC=c("none", "aic", "hqic"
                 ic$QHC<-lk-2*(lk-bic)*log(log(n))/log(n)}
         }
         ans<-list(p=res[[3]][1:m[1]],
-            mloglik=mloglik, m=optim, lk=lk, lr=res[[9]][1:k], M=M, support=c(a,b),
+            mloglik=mloglik, m=optim, lk=lk, lr=res[[9]][1:k], M=M, interval=c(a,b),
             convergence=res[[12]], del=res[[13]], ic=ic, pval=res[[16]][1:(k+1)],
             chpts=res[[17]][1:(k+1)]+M[1])
     }
@@ -378,22 +377,47 @@ mable.group<-function(x, breaks, M, interval=c(0, 1), IC=c("none", "aic", "hqic"
     return(ans)
 }
 ##############################################
-#        fm(x; p) or Fm(x;p)
-##############################################
-# Returns n-dim row vector, n=length(x)
-#' Bernstein polynomials
-#' @description The Bernstein polynomials at \code{x} with coefficients \code{p} on an \code{interval}
-#' @param x sequence of values in (a,b) at which density/distribution function to be evaluated
-#' @param p mixing proportions. The \code{m+1} components of \code{p} must be nonnegative.
-#' @param interval a vector containing the endpoints of supporting/truncation interval
-#' @param density logical, whether a density or a distribution function to be calculated. Default is TRUE.
-#' @return A vector of \eqn{f_m(x; p)} or \eqn{F_m(x; p)} values at \eqn{x}
+#' Mixture Beta Distribution
+#' @description Density, distribution function, quantile function and
+#' pseudorandom number generation for the Bernstein polynomial model,
+#' mixture of beta distributions, with shapes \eqn{(i+1, m-i+1)}, \eqn{i = 0, \ldots, m},
+#'  given mixture proportions \eqn{p = (p_0, \ldots, p_m)} and support \code{interval}.
+#' @param x a vector of quantiles
+#' @param u a vector of probabilities
+#' @param n sample size
+#' @param p a vector of \code{m+1} values. The \code{m+1} components of \code{p}
+#'   must be nonnegative and sum to one for mixture beta distribution. See 'Details'.
+#' @param interval support/truncation interval \code{[a, b]}.
+#' @return A vector of \eqn{f_m(x; p)} or \eqn{F_m(x; p)} values at \eqn{x}.
+#' \code{dmixbeta} returns the density, \code{pmixbeta} returns the cumulative
+#'  distribution function, \code{qmixbeta} returns the quantile function, and
+#' \code{rmixbeta}  generates pseudo random numbers.
+#' @details
+#'  The density of the mixture beta distribution on an interval \eqn{[a, b]} can be written as a
+#'  Bernstein polynomial \eqn{f_m(x; p) = \sum_{i=0}^m p_i\beta_{mi}[(x-a)/(b-a)]/(b-a)},
+#'  where \eqn{p = (p_0, \ldots, p_m)}, \eqn{p_i\ge 0}, \eqn{\sum_{i=0}^m p_i=1} and
+#'  \eqn{\beta_{mi}(u) = (m+1){m\choose i}u^i(1-x)^{m-i}}, \eqn{i = 0, 1, \ldots, m},
+#'  is the beta density with shapes \eqn{(i+1, m-i+1)}. The cumulative distribution
+#' function is \eqn{F_m(x; p) = \sum_{i=0}^m p_i B_{mi}[(x-a)/(b-a)]}, where
+#' \eqn{B_{mi}(u)}, \eqn{i = 0, 1, \ldots, m}, is the beta cumulative distribution function
+#'  with shapes \eqn{(i+1, m-i+1)}. If \eqn{\pi = \sum_{i=0}^m p_i<1}, then \eqn{f_m/\pi}
+#'   is a truncated desity on \eqn{[a, b]} with cumulative distribution function
+#'  \eqn{F_m/\pi}. The argument \code{p} may be any numeric vector of \code{m+1}
+#'  values when \code{pmixbeta()} and and \code{qmixbeta()} return the integral
+#'  function \eqn{F_m(x; p)} and its inverse, respectively, and \code{dmixbeta()}
+#'  returns a Bernstein polynomial \eqn{f_m(x; p)}.
 #' @author Zhong Guan <zguan@iusb.edu>
 #' @references
+#' Bernstein, S.N. (1912), Demonstration du theoreme de Weierstrass fondee sur le calcul des probabilities,
+#' Communications of the Kharkov Mathematical Society, 13, 1–2.
+#'
 #' Guan, Z. (2016) Efficient and robust density estimation using Bernstein type polynomials. \emph{Journal of Nonparametric Statistics}, 28(2):250-271.
+#'
 #' Guan, Z. (2017) Bernstein polynomial model for grouped continuous data. \emph{Journal of Nonparametric Statistics}, 29(4):831-848.
-#' @seealso \code{\link{mable}}
 #' @keywords distribution  models  nonparametric  smooth
+#' @concept Bernstein polynomial model
+#' @concept Mixture beta distribution
+#' @seealso \code{\link{mable}}
 #' @examples
 #' # classical Bernstein polynomial approximation
 #' a<--4; b<-4; m<-200
@@ -401,33 +425,118 @@ mable.group<-function(x, breaks, M, interval=c(0, 1), IC=c("none", "aic", "hqic"
 #' u<-(0:m)/m
 #' p<-dnorm(a+(b-a)*u)
 #' plot(x, dnorm(x), type="l")
-#' lines(x, (b-a)*bern.poly(x, p, c(a, b))/(m+1), lty=2, col=2)
+#' lines(x, (b-a)*dmixbeta(x, p, c(a, b))/(m+1), lty=2, col=2)
 #' legend(a, dnorm(0), lty=1:2, col=1:2, c(expression(f(x)==phi(x)),
 #'                expression(B^{f}*(x))))
 #'
-# @useDynLib mable mable_approx .registration = TRUE
-#' @keywords  distribution  models  nonparametric  smooth
-#' @concept Bernstein polynomial model
+#' @importFrom stats dunif punif qunif runif uniroot rbeta
 #' @export
-bern.poly<-function(x, p, interval=c(0, 1), density=TRUE){
-    m<-length(p)-1
-    if(any(p<0)) stop("Negative mixture proportion.")
+dmixbeta<-function(x, p, interval=c(0, 1)){
     n<-length(x)
     a<-interval[1]
     b<-interval[2]
     if(a>=b) stop("a must be smaller than b")
-    u<-(x-a)/(b-a)
-#    cdf<-!density
-    res<-.C("mable_approx",
-      as.double(u), as.double(p), as.integer(m), as.integer(n), as.logical(!density))
-    if(density) res[[1]]/(b-a)
-    else res[[1]]
+    if(any(x<a) || any(x>b)) stop("Argument 'x' must be in 'interval'.")
+    if(length(p)==0) stop("Missing mixture proportions 'p' without default.")
+    if(any(p<0)) warning("Argument 'p' has negative component(s).\n")
+    #else if(abs(sum(p)-1)>.Machine$double.eps){
+    #    if(sum(p)<1) warning("Sum of 'p's is less than 1.\n")
+    #    else warning("Sum of 'p's is bigger than 1.\n")
+    #}
+    m<-length(p)-1
+    if(m==0) y<-dunif(x, a, b)
+    else{
+        cdf<-FALSE
+        u<-(x-a)/(b-a)
+        res<-.C("mable_approx",
+          as.double(u), as.double(p), as.integer(m), as.integer(n), as.logical(cdf))
+        y<-res[[1]]/(b-a)
+    }
+    return(y)
+}
+#' @rdname dmixbeta
+#' @export
+pmixbeta<-function(x, p, interval=c(0, 1)){
+    n<-length(x)
+    a<-interval[1]
+    b<-interval[2]
+    if(a>=b) stop("a must be smaller than b")
+    if(any(x<a) || any(x>b)) stop("Argument 'x' must be in 'interval'.")
+    if(length(p)==0) stop("Missing mixture proportions 'p' without default.")
+    if(any(p<0)) warning("Argument 'p' has negative component(s).\n")
+    #else if(abs(sum(p)-1)>.Machine$double.eps){
+    #    if(sum(p)<1) warning("Sum of 'p's is less than 1.\n")
+    #    else warning("Sum of 'p's is bigger than 1. \n")
+    #}
+    m<-length(p)-1
+    if(m==0) y<-punif(x, a, b)
+    else{
+        cdf<-TRUE
+        u<-(x-a)/(b-a)
+        res<-.C("mable_approx",
+          as.double(u), as.double(p), as.integer(m), as.integer(n), as.logical(cdf))
+        y<-res[[1]]
+    }
+    return(y)
+}
+#' @rdname dmixbeta
+#' @export
+#########################################################
+# another method is Newton-Raphson as 'mable-roc.r'
+#########################################################
+qmixbeta<-function(u, p, interval=c(0, 1)){
+    a<-interval[1]
+    b<-interval[2]
+    if(a>=b) stop("a must be smaller than b")
+    if(any(u<0) || any(u>1)) stop("Argument 'u' must be in [0,1].\n")
+    if(length(p)==0) stop("Missing mixture proportions 'p' without default.")
+    if(any(p<0)) warning("Argument 'p' has negative component(s).\n")
+    #else if(abs(sum(p)-1)>.Machine$double.eps){
+    #    if(sum(p)<1) warning("Sum of 'p's is less than 1.\n")
+    #    else warning("Sum of 'p's is bigger than 1. \n")
+    #}
+    m<-length(p)-1
+    if(m==0) Q<-qunif(u, a, b)
+    else{
+        n<-length(u)
+        Q<-u
+        for(i in 2:(n-1)){
+            fn<-function(x) pmixbeta(x, p=p)-1+u[i]
+            Q[i]<-uniroot(fn, c(0,1))$root
+        }
+        Q<-a+(b-a)*Q
+    }
+    return(Q)
+}
+#' @rdname dmixbeta
+#' @export
+#########################################################################
+# generating prn from sum(p[i]*beta[m,i][(x-a)/(b-a)]/(b-a): i=0,...,m)
+#########################################################################
+rmixbeta<-function(n, p, interval=c(0, 1)){
+    a<-interval[1]
+    b<-interval[2]
+    if(a>=b) stop("a must be smaller than b")
+    if(length(p)==0) stop("Missing mixture proportions 'p' without default.")
+    if(any(p<0)) stop("Negative component(s) of argument 'p'is not allowed.\n")
+    if(abs(sum(p)-1)>.Machine$double.eps){
+        warning("Sum of 'p's is not 1. Dividing 'p's by the total.\n")
+            p<-p/sum(p)
+    }
+    m<-length(p)-1
+    if(m==0) x<-runif(n, a, b)
+    else{
+        w<-sample(0:m, n, replace = T, prob = p)
+        x<-rbeta(n, shape1 = w+1, shape2 = m-w+1)
+        x<-a+(b-a)*x
+    }
+    return(x)
 }
 ##############################################
 #' Plot mathod for class 'mable'
 ##############################################
 #' @param x  Class "mable" object return by \code{mablem}, \code{mable}, \code{mablem.group} or \code{mable.group} functions
-#'      which contains \code{p}, \code{mloglik}, and \code{M=m0:m1}, \code{lk}, \code{lr},
+#'      which contains \code{p}, \code{mloglik}, and \code{M = m0:m1}, \code{lk}, \code{lr},
 #' @param which indicates which graphs to plot, options are
 #'  "density", "cumulative", "likelihood", "change-point", "all". If not "all",
 #'  \code{which} can contain more than one options.
@@ -445,7 +554,7 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
     if(is.null(x$dim)) dim<-1
     else dim<-x$dim
     if(dim>2) stop("There is no method to 'plot' the object.\n")
-    support<-x$support
+    support<-x$interval
     if(is.null(lgd.x)) lgd.x="topright"
     which <- match.arg(which, several.ok=TRUE)
     if(dim==1){
@@ -481,7 +590,7 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
             axis(1, m,  as.character(m), ...)}
     }
     if(any(which=="density")||any(which=="all")){
-        yy<-bern.poly(xx, phat[1:(m+1)], c(a, b), density=TRUE)
+        yy<-dmixbeta(xx, phat[1:(m+1)], c(a, b))
         if(!add)
             plot(xx, yy, type="l",  ylab="Density", xlim=c(a, b), ...)
         else
@@ -489,9 +598,9 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
     }
     if(any(which=="cumulative")||any(which=="survival")||any(which=="all")){
         if(any(which=="survival")||any(which=="all"))
-            yy<-1-bern.poly(xx, phat[1:(m+1)], c(a, b), density=FALSE)
+            yy<-1-pmixbeta(xx, phat[1:(m+1)], c(a, b))
         else
-            yy<-bern.poly(xx, phat[1:(m+1)], c(a, b), density=FALSE)
+            yy<-pmixbeta(xx, phat[1:(m+1)], c(a, b))
         if(!add) {
             if(any(which=="survival")||any(which=="all")) plot(xx, yy,
                 type="l", ylab="Survival Probability", xlim=c(a,b), col=1, ...)
@@ -508,7 +617,7 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
         }
         if(any(which=="all")) op<-par(mfrow=c(2,1))
         if(any(which=="density")||any(which=="all")){
-            fn<-function(x1, x2) mvbern.poly(cbind(x1, x2), x)
+            fn<-function(x1, x2) dmixmvbeta(cbind(x1, x2), phat, m, support)
             x1 <- seq(a[1], b[1], length= 40)
             x2 <- seq(a[2], b[2], length= 40)
             z1 <- outer(x1, x2, fn)
@@ -517,7 +626,7 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
               xlab = x$xNames[1], ylab = x$xNames[2], zlab = "Joint Density")
         }
         if(any(which=="cumulative")||any(which=="all")){
-            fn<-function(x1, x2) mvbern.poly(cbind(x1, x2), x, density=FALSE)
+            fn<-function(x1, x2) pmixmvbeta(cbind(x1, x2), phat, m, support)
             x1 <- seq(a[1], b[1], length= 40)
             x2 <- seq(a[2], b[2], length= 40)
             z2 <- outer(x1, x2, fn)
@@ -533,14 +642,14 @@ plot.mable<-function(x, which=c("density", "cumulative", "survival", "likelihood
 ##############################################
 #' @param object  Class "mable" or 'mable_reg' object return by \code{mable} or \code{mable.xxxx}  functions
 #' @param ...  for future methods
-#' @description Produces a summary of a mable fit
+#' @description Produces a summary of a mable fit.
 #' @return Invisibly returns its argument, \code{object}.
 #' @examples
 #' \donttest{
 #'   # Vaal Rive Flow Data
 #'   data(Vaal.Flow)
-#'   res<-mable(Vaal.Flow$Flow, M=c(2,100), interval=c(0, 3000),
-#'      controls =mable.ctrl(sig.level=1e-8, maxit=2000, eps=1.0e-9))
+#'   res<-mable(Vaal.Flow$Flow, M = c(2,100), interval = c(0, 3000),
+#'      controls = mable.ctrl(sig.level = 1e-8, maxit = 2000, eps = 1.0e-9))
 #'   summary(res)
 #' }
 #' \donttest{
@@ -579,7 +688,7 @@ summary.mable<-function(object, ...){
         noisy=cat("Call: mable.decon() for noisy data"))
     cat("\nObj Class:", cl,"\n")
     cat("Input Data:", obj$xNames,"\n")
-    cat("Dimsion of data:", ans$dim,"\n")
+    cat("Dimension of data:", ans$dim,"\n")
     if(obj$data.type=="mvar"){
         cat("Optimal degrees:\n")
         prnt<-cbind(ans$m, ans$pval)
@@ -618,8 +727,8 @@ summary.mable_reg<-function(object, ...){
     cat(paste("Call: ",obj$model,"(",obj$callText,")", sep=''))
     cat("\nData:", obj$data.name,"\n")
     cat("Obj Class:", cl,"\n")
-    cat("Dimsion of response:", ans$dim,"\n")
-    cat("Dimsion of covariate:", ans$dimcov,"\n")
+    cat("Dimension of response:", ans$dim,"\n")
+    cat("Dimension of covariate:", ans$dimcov,"\n")
     cat("Optimal degree m:", ans$m,"\n")
     cat("P-value:", ans$pval,"\n")
     cat("Maximum loglikelihood:", ans$mloglik,"\n")
@@ -636,16 +745,16 @@ summary.mable_reg<-function(object, ...){
 #' Choosing optimal model degree by gamma change-point method
 #' @description Choose an optimal degree using gamma change-point model with two
 #'   changing shape and scale parameters.
-#' @param obj a class "mable" or 'mable_reg' object containig a vector \code{M=(m0,m1)}, \code{lk},
-#'    loglikelihoods evaluated evaluated at \eqn{m\in\{m_0,\ldots, m_1\}}
+#' @param obj a class "mable" or 'mable_reg' object containig a vector \code{M = (m0, m1)}, \code{lk},
+#'    loglikelihoods evaluated evaluated at \eqn{m \in \{m_0, \ldots, m_1\}}
 #' @return a list with components
 #' \itemize{
 #'   \item \code{m} the selected optimal degree \code{m}
-#'   \item \code{M} the vector \code{(m0,m1)}, where \code{m1} is the last candidate when the search stoped
+#'   \item \code{M} the vector \code{(m0, m1)}, where \code{m1} is the last candidate when the search stoped
 #'   \item \code{mloglik}  the maximum log-likelihood at degree \code{m}
-#'   \item \code{support} supporting interval \code{(a,b)}
-#'   \item \code{lk} log-likelihoods evaluated at \eqn{m\in\{m_0,\ldots, m_1\}}
-#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m\in\{m_0+1,\ldots, m_1\}}
+#'   \item \code{interval} support/truncation interval \code{(a, b)}
+#'   \item \code{lk} log-likelihoods evaluated at \eqn{m \in \{m_0, \ldots, m_1\}}
+#'   \item \code{lr} likelihood ratios for change-points evaluated at \eqn{m \in \{m_0+1, \ldots, m_1\}}
 #'   \item \code{pval} the p-values of the change-point tests for choosing optimal model degree
 #'   \item \code{chpts} the change-points chosen with the given candidate model degrees
 #' }
@@ -668,8 +777,8 @@ summary.mable_reg<-function(object, ...){
 #' }
 #' @export
 optim.gcp<-function(obj){
-    M=obj$M
-    lk=obj$lk
+    M<-obj$M
+    lk<-obj$lk
     k<-M[2]-M[1]
     lr<-rep(0, k)
     pval<-rep(0, k+1)
@@ -678,25 +787,7 @@ optim.gcp<-function(obj){
     res<-.C("optim_gcp", as.integer(M), as.double(lk), as.double(lr), as.integer(m),
         as.double(pval), as.integer(chpts))
     ans<-list(m=res[[4]], M=M, mloglik=lk[res[[4]]-M[1]+1], lk=lk, lr=res[[3]],
-        support=obj$support, pval=res[[5]], chpts=res[[6]]+M[1])
+        interval=obj$interval, pval=res[[5]], chpts=res[[6]]+M[1])
     class(ans)<-"mable"
     return(ans)
 }
-#########################################################
-# generating prn from sum(p[i]*beta[m,i](x): i=0,...,m)
-#########################################################
-#' Generate data from Bernstein polynomial model
-#' Generate random sample from mixture of beta distributions with
-#'  shapes \eqn{(i+1, m-i+1)}, \eqn{i=0,\ldots,m}, with given mixture
-#'  proportions \eqn{p=(p_0, \ldots,p_m)}.
-#' @param n sample size
-#' @param p a vector of mixture proportions, must contain at least four components
-#' @importFrom stats rbeta
-#' @export
-rmixbeta<-function(n, p){
-    if(length(p)==0) stop("Missing mixture proportions 'p' without default.")
-    if(length(p)<=3) stop("'p' must contain at least four components.")
-    m<-length(p)-1
-    w<-sample(0:m, n, replace = T, prob = p)
-    rbeta(n, shape1 = w+1, shape2 = m-w+1)
-}
